(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 11.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     88799,       2420]
NotebookOptionsPosition[     84249,       2284]
NotebookOutlinePosition[     84598,       2299]
CellTagsIndexPosition[     84555,       2296]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.7707007393066063`*^9, 3.7707007399988194`*^9}}],

Cell[CellGroupData[{

Cell["Maximally symmetric spaces in 3D", "Section",
 CellChangeTimes->{{3.770700422864107*^9, 3.7707004307202797`*^9}}],

Cell["\<\
See cosmology section of [Carroll, S. M. (2004). An introduction to general \
relativity. Spacetime and Geometry. Addison Wesley]. In this notebook, we \
derive the metric of a maximally-symmetric space using xCoba.\
\>", "Text",
 CellChangeTimes->{{3.79282154208039*^9, 3.792821545865303*^9}, {
  3.792821594009855*^9, 3.792821615277504*^9}, {3.792821696208782*^9, 
  3.7928217313295193`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"import", " ", "xTensor", " ", "and", " ", "xCoba"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"<<", "xAct`xTensor`"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"<<", "xAct`xCoba`"}], ";"}]}]}]], "Input",
 CellChangeTimes->{{3.770700418961774*^9, 3.7707004195997634`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014686575036`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xPerm`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.2.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2015", ",", "8", ",", "23"}], "}"}]}],
  SequenceForm["Package xAct`xPerm`  version ", "1.2.3", ", ", {2015, 8, 23}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014686614103`*^9}],

Cell[BoxData["\<\"CopyRight (C) 2003-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014686634054`*^9}],

Cell[BoxData["\<\"Connecting to external MinGW executable...\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701468707443*^9}],

Cell[BoxData["\<\"Connection established.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014688171215`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014688269725`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xTensor`  version \"\>", 
   "\[InvisibleSpace]", "\<\"1.1.3\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm[
  "Package xAct`xTensor`  version ", "1.1.3", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701468836706*^9}],

Cell[BoxData["\<\"CopyRight (C) 2002-2018, Jose M. Martin-Garcia, under the \
General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014688513784`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701468861043*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014688686438`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014688771324`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.77070146905788*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Package xAct`xCoba`  version \"\>", 
   "\[InvisibleSpace]", "\<\"0.8.4\"\>", "\[InvisibleSpace]", "\<\", \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"{", 
    RowBox[{"2018", ",", "2", ",", "28"}], "}"}]}],
  SequenceForm["Package xAct`xCoba`  version ", "0.8.4", ", ", {2018, 2, 28}],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701469062919*^9}],

Cell[BoxData["\<\"CopyRight (C) 2005-2018, David Yllanes and Jose M. \
Martin-Garcia, under the General Public License.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701469067086*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.77070146907069*^9}],

Cell[BoxData["\<\"These packages come with ABSOLUTELY NO WARRANTY; for \
details type Disclaimer[]. This is free software, and you are welcome to \
redistribute it under certain conditions. See the General Public License for \
details.\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.7707014690736732`*^9}],

Cell[BoxData["\<\"------------------------------------------------------------\
\"\>"], "Print",
 CellChangeTimes->{3.7707004341121516`*^9, 3.7707007532545195`*^9, 
  3.7707009801003265`*^9, 3.7707010627338896`*^9, 3.770701469076921*^9}]
}, Open  ]]
}, Open  ]],

Cell["\<\
In this notebook, we derive maximally-symmetric spaces in three dimensions.\
\>", "Text",
 CellChangeTimes->{{3.770700357231501*^9, 3.770700381940138*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", "optional", "*)"}], "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"$CovDFormat", "=", "\"\<Prefix\>\""}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"$PrePrint", "=", "ScreenDollarIndices"}], ";"}], "\n", 
   RowBox[{
    RowBox[{"Options", "[", "MakeRule", "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"Options", "[", "ContractMetric", "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "manifold", " ", "and", " ", "metric"}], "*)"}], 
   "                                ", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefManifold", "[", 
     RowBox[{"MS", ",", "3", ",", 
      RowBox[{"{", 
       RowBox[{
       "\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]", ",", "\[Zeta]", ",", 
        "\[Xi]", ",", "\[Sigma]", ",", "\[Tau]", ",", "\[Omega]"}], "}"}]}], 
     "]"}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefMetric", "[", 
     RowBox[{
      RowBox[{"-", "1"}], ",", 
      RowBox[{"G", "[", 
       RowBox[{
        RowBox[{"-", "\[Alpha]"}], ",", 
        RowBox[{"-", "\[Beta]"}]}], "]"}], ",", "cd", ",", 
      RowBox[{"{", 
       RowBox[{"\"\<;\>\"", ",", "\"\<\[Del]\>\""}], "}"}], ",", 
      RowBox[{"WeightedWithBasis", "\[Rule]", "AIndex"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"PrintAs", "[", "Riemanncd", "]"}], "^=", "\"\<R\>\""}], ";", 
    " ", 
    RowBox[{
     RowBox[{"PrintAs", "[", "Riccicd", "]"}], "^=", "\"\<R\>\""}], ";", " ", 
    RowBox[{
     RowBox[{"PrintAs", "[", "RicciScalarcd", "]"}], "^=", "\"\<R\>\""}], ";",
     " ", 
    RowBox[{
     RowBox[{"PrintAs", "[", "Christoffelcd", "]"}], "^=", 
     "\"\<\[CapitalGamma]\>\""}], ";", " ", 
    RowBox[{
     RowBox[{"PrintAs", "[", "Einsteincd", "]"}], "^=", "\"\<G\>\""}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"define", " ", "an", " ", "xCoba", " ", "chart"}], "*)"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefChart", "[", 
     RowBox[{"SP", ",", "MS", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"r", "[", "]"}], ",", 
        RowBox[{"\[Theta]", "[", "]"}], ",", 
        RowBox[{"\[CurlyPhi]", "[", "]"}]}], "}"}]}], "]"}], ";"}], 
   "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "metric", " ", "in", " ", "spherical", " ", "polar", " ", "coordinates"}],
     "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"DefScalarFunction", "[", "Q", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"metric", "=", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"Q", "[", 
          RowBox[{"r", "[", "]"}], "]"}], ",", "0", ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", 
         SuperscriptBox[
          RowBox[{"r", "[", "]"}], "2"], ",", "0"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"0", ",", "0", ",", 
         RowBox[{
          SuperscriptBox[
           RowBox[{"r", "[", "]"}], "2"], 
          SuperscriptBox[
           RowBox[{"Sin", "[", 
            RowBox[{"\[Theta]", "[", "]"}], "]"}], "2"]}]}], "}"}]}], "}"}]}],
     ";"}], "\[IndentingNewLine]", "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "tell", " ", "xCoba", " ", "that", " ", "frw", " ", "is", " ", "the", " ",
      "metric", " ", "and", " ", "to", " ", "compute", " ", "the", " ", 
     "curvature", " ", "quantities"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricInBasis", "[", 
     RowBox[{"G", ",", 
      RowBox[{"-", "SP"}], ",", "metric"}], "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"MetricCompute", "[", 
     RowBox[{"G", ",", "SP", ",", "All", ",", 
      RowBox[{"CVSimplify", "\[Rule]", "Simplify"}]}], "]"}], 
    ";"}]}]}]], "Input",
 CellChangeTimes->{{3.7707004444482484`*^9, 3.7707005221415477`*^9}, {
  3.77070058006707*^9, 3.7707007261819234`*^9}, {3.7707009615260396`*^9, 
  3.7707009726445684`*^9}, {3.7707010040438156`*^9, 3.7707010042059016`*^9}, {
  3.7707010362828293`*^9, 3.7707010540750055`*^9}, {3.7707015030904045`*^9, 
  3.7707015205128546`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefManifold", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"manifold \"\>", "\[InvisibleSpace]", "MS", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefManifold, ": Defining ", 
   "manifold ", $CellContext`MS, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015254785757`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefVBundle", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vbundle \"\>", "\[InvisibleSpace]", "TangentMS", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefVBundle, ": Defining ", 
   "vbundle ", $CellContext`TangentMS, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525482681*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric metric tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"G", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric metric tensor ", 
   $CellContext`G[-$CellContext`\[Alpha], -$CellContext`\[Beta]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525499647*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"epsilonG", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric tensor ", 
   $CellContext`epsilonG[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525505228*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"covariant derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"cd", "[", 
    RowBox[{"-", "\[Alpha]"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "covariant derivative ", 
   $CellContext`cd[-$CellContext`\[Alpha]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015255086484`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Torsioncd", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`Torsioncd[$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525515364*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Christoffelcd", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`Christoffelcd[$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525519168*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Riemann tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Riemanncd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}], ",", 
     RowBox[{"-", "\[Zeta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Riemann tensor ", 
   $CellContext`Riemanncd[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma], -$CellContext`\[Zeta]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525522487*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Riccicd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Ricci tensor ", 
   $CellContext`Riccicd[-$CellContext`\[Alpha], -$CellContext`\[Beta]], ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525525113*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Riemann automatically replaced \
by Ricci.\"\>"], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525530586*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Ricci scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"RicciScalarcd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "Ricci scalar ", 
   $CellContext`RicciScalarcd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525548126*^9}],

Cell[BoxData["\<\"** DefCovD:  Contractions of Ricci automatically replaced \
by RicciScalar.\"\>"], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015255661073`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Einstein tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"Einsteincd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric Einstein tensor ", 
   $CellContext`Einsteincd[-$CellContext`\[Alpha], -$CellContext`\[Beta]], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525569876*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Weyl tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"Weylcd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}], ",", 
     RowBox[{"-", "\[Zeta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Weyl tensor ", 
   $CellContext`Weylcd[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma], -$CellContext`\[Zeta]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525607012*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric TFRicci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TFRiccicd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "symmetric TFRicci tensor ", 
   $CellContext`TFRiccicd[-$CellContext`\[Alpha], -$CellContext`\[Beta]], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525613404*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"Kretschmann scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"Kretschmanncd", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "Kretschmann scalar ", 
   $CellContext`Kretschmanncd[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015256473227`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RiemannToWeylRules for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RiemannToWeylRules for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015256509867`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToTFRicci for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RicciToTFRicci for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015256551943`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** DefCovD:  Computing RicciToEinsteinRules for dim \"\>", 
   "\[InvisibleSpace]", "3"}],
  SequenceForm["** DefCovD:  Computing RicciToEinsteinRules for dim ", 3],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015256737823`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetG", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetG[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015256967945`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefChart", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"chart \"\>", "\[InvisibleSpace]", "SP", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefChart, ": Defining ", "chart ", $CellContext`SP, ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525700156*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"r", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`r[], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525704215*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[Theta]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[Theta][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525708582*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"coordinate scalar \"\>", "\[InvisibleSpace]", 
   RowBox[{"\[CurlyPhi]", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "coordinate scalar ", 
   $CellContext`\[CurlyPhi][], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525713601*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping \"\>", "\[InvisibleSpace]", "SP", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", "mapping ", $CellContext`SP, 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015257172422`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefMapping", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"inverse mapping \"\>", "\[InvisibleSpace]", 
   "iSP", "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefMapping, ": Defining ", 
   "inverse mapping ", $CellContext`iSP, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525720845*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"diSP", "[", 
    RowBox[{
     RowBox[{"-", "\[FormalA]"}], ",", "iSP\[Alpha]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`diSP[-\[FormalA], $CellContext`iSP\[Alpha]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525724951*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"mapping differential tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"dSP", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", "SP\[FormalA]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "mapping differential tensor ", 
   $CellContext`dSP[-$CellContext`\[Alpha], $CellContext`SP\[FormalA]], ". ", 
   ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.77070152573057*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefBasis", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"basis \"\>", "\[InvisibleSpace]", "SP", 
   "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Coordinated basis.\"\>"}],
  SequenceForm[
  "** ", xAct`xCoba`DefBasis, ": Defining ", "basis ", $CellContext`SP, ". ", 
   "Coordinated basis."],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525735077*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefCovD", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"parallel derivative \"\>", "\[InvisibleSpace]", 
   RowBox[{"PDSP", "[", 
    RowBox[{"-", "\[Alpha]"}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefCovD, ": Defining ", "parallel derivative ", 
   $CellContext`PDSP[-$CellContext`\[Alpha]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525740246*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing torsion tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"TorsionPDSP", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing torsion tensor ", 
   $CellContext`TorsionPDSP[$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015257451158`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"symmetric Christoffel tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"ChristoffelPDSP", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", 
   "symmetric Christoffel tensor ", 
   $CellContext`ChristoffelPDSP[$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525749055*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Riemann tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RiemannPDSP", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}], ",", "\[Zeta]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Riemann tensor ", 
   $CellContext`RiemannPDSP[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma], $CellContext`\[Zeta]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525752695*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"vanishing Ricci tensor \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"RicciPDSP", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "vanishing Ricci tensor ", 
   $CellContext`RicciPDSP[-$CellContext`\[Alpha], -$CellContext`\[Beta]], 
   ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525758374*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric +1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaUpSP", "[", 
    RowBox[{"\[Alpha]", ",", "\[Beta]", ",", "\[Gamma]"}], "]"}], 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric +1 density ", 
   $CellContext`etaUpSP[$CellContext`\[Alpha], $CellContext`\[Beta], \
$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015257637186`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"antisymmetric -1 density \"\>", 
   "\[InvisibleSpace]", 
   RowBox[{"etaDownSP", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "antisymmetric -1 density ", 
   $CellContext`etaDownSP[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.77070152576869*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefScalarFunction", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"scalar function \"\>", "\[InvisibleSpace]", "Q", 
   "\[InvisibleSpace]", "\<\". \"\>", "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefScalarFunction, ": Defining ", 
   "scalar function ", $CellContext`Q, ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015257731647`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{1, -$CellContext`SP}, {1, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", 
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "]"}]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{1, -$CellContext`SP}, {
     1, -$CellContext`SP}] -> $CellContext`Q[
     $CellContext`r[]], " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525779455*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{1, -$CellContext`SP}, {2, -$CellContext`SP}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{1, -$CellContext`SP}, {
     2, -$CellContext`SP}] -> 0, " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525795379*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{1, -$CellContext`SP}, {3, -$CellContext`SP}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{1, -$CellContext`SP}, {
     3, -$CellContext`SP}] -> 0, " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525804278*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{2, -$CellContext`SP}, {1, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{1, -$CellContext`SP}, {2, -$CellContext`SP}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`G[{2, -$CellContext`SP}, {
     1, -$CellContext`SP}] -> $CellContext`G[{1, -$CellContext`SP}, {
     2, -$CellContext`SP}], " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015258232837`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{2, -$CellContext`SP}, {2, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    SuperscriptBox[
     InterpretationBox[
      StyleBox["r",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`r[],
      Editable->False], "2"]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{2, -$CellContext`SP}, {
     2, -$CellContext`SP}] -> $CellContext`r[]^2, 
   " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.77070152583053*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{2, -$CellContext`SP}, {3, -$CellContext`SP}],
     Editable->False], "\[Rule]", "0"}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{2, -$CellContext`SP}, {
     3, -$CellContext`SP}] -> 0, " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015258458185`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{3, -$CellContext`SP}, {1, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["1",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{1, -$CellContext`SP}, {3, -$CellContext`SP}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`G[{3, -$CellContext`SP}, {
     1, -$CellContext`SP}] -> $CellContext`G[{1, -$CellContext`SP}, {
     3, -$CellContext`SP}], " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525866968*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added dependent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{3, -$CellContext`SP}, {2, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["2",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{2, -$CellContext`SP}, {3, -$CellContext`SP}],
     Editable->False]}], "\[InvisibleSpace]", "\<\" for tensor \"\>", 
   "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added dependent rule ", $CellContext`G[{3, -$CellContext`SP}, {
     2, -$CellContext`SP}] -> $CellContext`G[{2, -$CellContext`SP}, {
     3, -$CellContext`SP}], " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015258853693`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"Added independent rule \"\>", "\[InvisibleSpace]", 
   RowBox[{
    InterpretationBox[
     StyleBox[GridBox[{
        {"G", 
         StyleBox[GridBox[{
            {" ", " "},
            {
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]], 
             StyleBox["3",
              FontColor->RGBColor[1., 0., 0.]]}
           },
           GridBoxSpacings->{"Columns" -> {
               Offset[0.], {
                Offset[0.034999999999999996`]}, 
               Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                Offset[0.]}}, "RowsIndexed" -> {}}],
          FontSize->Rational[39, 4]]}
       },
       GridBoxAlignment->{
        "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}},
          "RowsIndexed" -> {}},
       GridBoxSpacings->{"Columns" -> {
           Offset[0.27999999999999997`], {
            Offset[0.034999999999999996`]}, 
           Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
           Offset[0.2], {
            Offset[0.4]}, 
           Offset[0.2]}, "RowsIndexed" -> {}}],
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`G[{3, -$CellContext`SP}, {3, -$CellContext`SP}],
     Editable->False], "\[Rule]", 
    RowBox[{
     SuperscriptBox[
      InterpretationBox[
       StyleBox["r",
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`r[],
       Editable->False], "2"], " ", 
     SuperscriptBox[
      RowBox[{
       InterpretationBox[
        StyleBox["Sin",
         ShowAutoStyles->False,
         AutoSpacing->False],
        Sin,
        Editable->False], "[", 
       InterpretationBox[
        StyleBox["\[Theta]",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`\[Theta][],
        Editable->False], "]"}], "2"]}]}], 
   "\[InvisibleSpace]", "\<\" for tensor \"\>", "\[InvisibleSpace]", "G"}],
  SequenceForm[
  "Added independent rule ", $CellContext`G[{3, -$CellContext`SP}, {
     3, -$CellContext`SP}] -> $CellContext`r[]^2 Sin[
       $CellContext`\[Theta][]]^2, " for tensor ", $CellContext`G],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.770701525905246*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"weight +2 density \"\>", "\[InvisibleSpace]", 
   RowBox[{"DetGSP", "[", "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"Determinant.\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefTensor, ": Defining ", "weight +2 density ", 
   $CellContext`DetGSP[], ". ", "Determinant."],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015259222383`*^9}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefTensor", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"tensor \"\>", "\[InvisibleSpace]", 
   RowBox[{"ChristoffelcdPDSP", "[", 
    RowBox[{"\[Alpha]", ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}]}], "]"}], "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm["** ", xAct`xTensor`DefTensor, ": Defining ", "tensor ", 
   $CellContext`ChristoffelcdPDSP[$CellContext`\[Alpha], \
-$CellContext`\[Beta], -$CellContext`\[Gamma]], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707008208365583`*^9, 3.770700989400868*^9, 
  3.7707010711695204`*^9, 3.7707015259628468`*^9}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
 "Maximally symmetric spaces are solutions to ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "abcd"], "=", 
    RowBox[{"\[Kappa]", "(", 
     RowBox[{
      RowBox[{
       SubscriptBox["g", "ac"], 
       SubscriptBox["g", "bd"]}], "-", 
      RowBox[{
       SubscriptBox["g", "ad"], 
       SubscriptBox["g", "bc"]}]}], ")"}]}], TraditionalForm]],
  FormatType->"TraditionalForm"],
 ". To proceed, we thus setup the left and right hand sides of this \
expressions."
}], "Text",
 CellChangeTimes->{{3.770701086477829*^9, 3.770701128954488*^9}, {
  3.770701188014143*^9, 3.7707011901575575`*^9}, {3.770701229800703*^9, 
  3.770701260158428*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"DefConstantSymbol", "[", "\[Kappa]", "]"}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"LHS", "=", 
   RowBox[{"Riemanncd", "[", 
    RowBox[{
     RowBox[{"-", "\[Alpha]"}], ",", 
     RowBox[{"-", "\[Beta]"}], ",", 
     RowBox[{"-", "\[Gamma]"}], ",", 
     RowBox[{"-", "\[Tau]"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"RHS", "=", 
    RowBox[{"\[Kappa]", 
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{
          RowBox[{"-", "\[Alpha]"}], ",", 
          RowBox[{"-", "\[Gamma]"}]}], "]"}], 
        RowBox[{"G", "[", 
         RowBox[{
          RowBox[{"-", "\[Beta]"}], ",", 
          RowBox[{"-", "\[Tau]"}]}], "]"}]}], "-", 
       RowBox[{
        RowBox[{"G", "[", 
         RowBox[{
          RowBox[{"-", "\[Alpha]"}], ",", 
          RowBox[{"-", "\[Tau]"}]}], "]"}], 
        RowBox[{"G", "[", 
         RowBox[{
          RowBox[{"-", "\[Beta]"}], ",", 
          RowBox[{"-", "\[Gamma]"}]}], "]"}]}]}], ")"}]}]}], ";"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
   "printing", " ", "the", " ", "defining", " ", "equation", " ", "for", " ", 
    "MS", " ", "spaces"}], "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{"LHS", "\[Equal]", "RHS"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.7707012617999754`*^9, 3.7707014368161583`*^9}}],

Cell[BoxData[
 InterpretationBox[
  RowBox[{"\<\"** \"\>", "\[InvisibleSpace]", "DefConstantSymbol", 
   "\[InvisibleSpace]", "\<\": Defining \"\>", 
   "\[InvisibleSpace]", "\<\"constant symbol \"\>", "\[InvisibleSpace]", 
   "\[Kappa]", "\[InvisibleSpace]", "\<\". \"\>", 
   "\[InvisibleSpace]", "\<\"\"\>"}],
  SequenceForm[
  "** ", xAct`xTensor`DefConstantSymbol, ": Defining ", 
   "constant symbol ", $CellContext`\[Kappa], ". ", ""],
  Editable->False]], "Print",
 CellChangeTimes->{3.7707015296709633`*^9}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"R", 
       StyleBox[GridBox[{
          {" ", " ", " ", " "},
          {"\[Alpha]", "\[Beta]", "\[Gamma]", "\[Tau]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`Riemanncd[-$CellContext`\[Alpha], -$CellContext`\[Beta], \
-$CellContext`\[Gamma], -$CellContext`\[Tau]],
   Editable->False], "\[Equal]", 
  RowBox[{
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", 
       InterpretationBox[
        StyleBox[GridBox[{
           {"G", 
            StyleBox[GridBox[{
               {" ", " "},
               {"\[Alpha]", "\[Tau]"}
              },
              GridBoxSpacings->{"Columns" -> {
                  Offset[0.], {
                   Offset[0.034999999999999996`]}, 
                  Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                   Offset[0.]}}, "RowsIndexed" -> {}}],
             FontSize->Rational[39, 4]]}
          },
          
          GridBoxAlignment->{
           "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
            "Rows" -> {{Center}}, "RowsIndexed" -> {}},
          GridBoxSpacings->{"Columns" -> {
              Offset[0.27999999999999997`], {
               Offset[0.034999999999999996`]}, 
              Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
              Offset[0.2], {
               Offset[0.4]}, 
              Offset[0.2]}, "RowsIndexed" -> {}}],
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`G[-$CellContext`\[Alpha], -$CellContext`\[Tau]],
        Editable->False]}], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"G", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G[-$CellContext`\[Beta], -$CellContext`\[Gamma]],
       Editable->False]}], "+", 
     RowBox[{
      InterpretationBox[
       StyleBox[GridBox[{
          {"G", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Alpha]", "\[Gamma]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G[-$CellContext`\[Alpha], -$CellContext`\[Gamma]],
       Editable->False], " ", 
      InterpretationBox[
       StyleBox[GridBox[{
          {"G", 
           StyleBox[GridBox[{
              {" ", " "},
              {"\[Beta]", "\[Tau]"}
             },
             GridBoxSpacings->{"Columns" -> {
                 Offset[0.], {
                  Offset[0.034999999999999996`]}, 
                 Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
                  Offset[0.]}}, "RowsIndexed" -> {}}],
            FontSize->Rational[39, 4]]}
         },
         GridBoxAlignment->{
          "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, 
           "Rows" -> {{Center}}, "RowsIndexed" -> {}},
         GridBoxSpacings->{"Columns" -> {
             Offset[0.27999999999999997`], {
              Offset[0.034999999999999996`]}, 
             Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
             Offset[0.2], {
              Offset[0.4]}, 
             Offset[0.2]}, "RowsIndexed" -> {}}],
        ShowAutoStyles->False,
        AutoSpacing->False],
       $CellContext`G[-$CellContext`\[Beta], -$CellContext`\[Tau]],
       Editable->False]}]}], ")"}]}]}]], "Output",
 CellChangeTimes->{{3.770701403165213*^9, 3.7707014311450477`*^9}, 
   3.7707015297050076`*^9}]
}, Open  ]],

Cell["\<\
Instead of solving this, we shall solve the contracted version...\
\>", "Text",
 CellChangeTimes->{{3.7707015873960876`*^9, 3.7707016575031705`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MSdef", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{"LHS", "\[Equal]", "RHS"}], ")"}], "/.", 
     RowBox[{"\[Alpha]", "\[Rule]", 
      RowBox[{"-", "\[Gamma]"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"contracted", " ", "version"}], 
   "*)"}]}], "\[IndentingNewLine]", "MSdef"}], "Input",
 CellChangeTimes->{{3.770701809848954*^9, 3.7707018606879735`*^9}}],

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   StyleBox[GridBox[{
      {"R", 
       StyleBox[GridBox[{
          {" ", " "},
          {"\[Beta]", "\[Tau]"}
         },
         GridBoxSpacings->{"Columns" -> {
             Offset[0.], {
              Offset[0.034999999999999996`]}, 
             Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
              Offset[0.]}}, "RowsIndexed" -> {}}],
        FontSize->Rational[39, 4]]}
     },
     GridBoxAlignment->{
      "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[0.034999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    ShowAutoStyles->False,
    AutoSpacing->False],
   $CellContext`Riccicd[-$CellContext`\[Beta], -$CellContext`\[Tau]],
   Editable->False], "\[Equal]", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   InterpretationBox[
    StyleBox[GridBox[{
       {"G", 
        StyleBox[GridBox[{
           {" ", " "},
           {"\[Beta]", "\[Tau]"}
          },
          GridBoxSpacings->{"Columns" -> {
              Offset[0.], {
               Offset[0.034999999999999996`]}, 
              Offset[0.]}, "ColumnsIndexed" -> {}, "Rows" -> {{
               Offset[0.]}}, "RowsIndexed" -> {}}],
         FontSize->Rational[39, 4]]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Center}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.034999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`G[-$CellContext`\[Beta], -$CellContext`\[Tau]],
    Editable->False]}]}]], "Output",
 CellChangeTimes->{{3.7707018339966297`*^9, 3.770701862790323*^9}}]
}, Open  ]],

Cell["Expressing this in spherical polar coordinates, we obtain...", "Text",
 CellChangeTimes->{{3.7707012865049767`*^9, 3.770701290206549*^9}, {
  3.7707014448932147`*^9, 3.770701458327018*^9}, {3.7707015338709974`*^9, 
  3.7707015373332357`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"MSdefcomp", "=", 
    RowBox[{
     RowBox[{"(", 
      RowBox[{
       RowBox[{
        RowBox[{"MSdef", "//", 
         RowBox[{"ToBasis", "[", "SP", "]"}]}], "//", "ComponentArray"}], "//",
        "ToValues"}], ")"}], "/.", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        RowBox[{"r", "[", "]"}], "\[Rule]", "r"}], ",", 
       RowBox[{
        RowBox[{"\[Theta]", "[", "]"}], "\[Rule]", "\[Theta]"}]}], "}"}]}]}], 
   ";"}], "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{"MSdefcomp", "//", "MatrixForm"}]}], "Input",
 CellChangeTimes->{{3.770701541669591*^9, 3.770701558019185*^9}, {
  3.7707018774486313`*^9, 3.7707019652550583`*^9}, {3.7707021773510017`*^9, 
  3.7707021797034073`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          InterpretationBox[
           StyleBox["Q",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Q,
           Editable->False], "\[Prime]",
          MultilineFunction->None], "[", "r", "]"}], 
        RowBox[{"r", " ", 
         RowBox[{
          InterpretationBox[
           StyleBox["Q",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Q,
           Editable->False], "[", "r", "]"}]}]], "\[Equal]", 
       RowBox[{"2", " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Q",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`Q,
          Editable->False], "[", "r", "]"}]}]}], "True", "True"},
     {"True", 
      RowBox[{
       RowBox[{"1", "-", 
        FractionBox["1", 
         RowBox[{
          InterpretationBox[
           StyleBox["Q",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`Q,
           Editable->False], "[", "r", "]"}]], "+", 
        FractionBox[
         RowBox[{"r", " ", 
          RowBox[{
           SuperscriptBox[
            InterpretationBox[
             StyleBox["Q",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Q,
             Editable->False], "\[Prime]",
            MultilineFunction->None], "[", "r", "]"}]}], 
         RowBox[{"2", " ", 
          SuperscriptBox[
           RowBox[{
            InterpretationBox[
             StyleBox["Q",
              ShowAutoStyles->False,
              AutoSpacing->False],
             $CellContext`Q,
             Editable->False], "[", "r", "]"}], "2"]}]]}], "\[Equal]", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False]}]}], "True"},
     {"True", "True", 
      RowBox[{
       FractionBox[
        RowBox[{
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Sin",
             ShowAutoStyles->False,
             AutoSpacing->False],
            Sin,
            Editable->False], "[", "\[Theta]", "]"}], "2"], " ", 
         RowBox[{"(", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "2"}], " ", 
            RowBox[{
             InterpretationBox[
              StyleBox["Q",
               ShowAutoStyles->False,
               AutoSpacing->False],
              $CellContext`Q,
              Editable->False], "[", "r", "]"}]}], "+", 
           RowBox[{"2", " ", 
            SuperscriptBox[
             RowBox[{
              InterpretationBox[
               StyleBox["Q",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Q,
               Editable->False], "[", "r", "]"}], "2"]}], "+", 
           RowBox[{"r", " ", 
            RowBox[{
             SuperscriptBox[
              InterpretationBox[
               StyleBox["Q",
                ShowAutoStyles->False,
                AutoSpacing->False],
               $CellContext`Q,
               Editable->False], "\[Prime]",
              MultilineFunction->None], "[", "r", "]"}]}]}], ")"}]}], 
        RowBox[{"2", " ", 
         SuperscriptBox[
          RowBox[{
           InterpretationBox[
            StyleBox["Q",
             ShowAutoStyles->False,
             AutoSpacing->False],
            $CellContext`Q,
            Editable->False], "[", "r", "]"}], "2"]}]], "\[Equal]", 
       RowBox[{"2", " ", 
        SuperscriptBox["r", "2"], " ", 
        InterpretationBox[
         StyleBox["\[Kappa]",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`\[Kappa],
         Editable->False], " ", 
        SuperscriptBox[
         RowBox[{
          InterpretationBox[
           StyleBox["Sin",
            ShowAutoStyles->False,
            AutoSpacing->False],
           Sin,
           Editable->False], "[", "\[Theta]", "]"}], "2"]}]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7707018845246987`*^9, 3.7707019176561975`*^9}, 
   3.7707019685810585`*^9, {3.770702168807354*^9, 3.7707021803763447`*^9}}]
}, Open  ]],

Cell[TextData[{
 "We can solve any of these (the system is redundant). For this example, we \
shall solve the ",
 StyleBox["rr",
  FontSlant->"Italic"],
 "-component given by..."
}], "Text",
 CellChangeTimes->{{3.7707019737461524`*^9, 3.7707020161801453`*^9}, {
  3.770702048386691*^9, 3.770702072826669*^9}, {3.7707021175334387`*^9, 
  3.7707021196388884`*^9}, {3.7707023380271616`*^9, 3.7707023382068615`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"accessing", " ", "the", " ", "rr"}], "-", "component"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{"MSdefcomp", "[", 
   RowBox[{"[", 
    RowBox[{"1", ",", "1"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.770702020500352*^9, 3.770702043223035*^9}, {
  3.7707020759297576`*^9, 3.770702113440984*^9}, {3.7707021708161383`*^9, 
  3.770702188177497*^9}}],

Cell[BoxData[
 RowBox[{
  FractionBox[
   RowBox[{
    SuperscriptBox[
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "\[Prime]",
     MultilineFunction->None], "[", "r", "]"}], 
   RowBox[{"r", " ", 
    RowBox[{
     InterpretationBox[
      StyleBox["Q",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`Q,
      Editable->False], "[", "r", "]"}]}]], "\[Equal]", 
  RowBox[{"2", " ", 
   InterpretationBox[
    StyleBox["\[Kappa]",
     ShowAutoStyles->False,
     AutoSpacing->False],
    $CellContext`\[Kappa],
    Editable->False], " ", 
   RowBox[{
    InterpretationBox[
     StyleBox["Q",
      ShowAutoStyles->False,
      AutoSpacing->False],
     $CellContext`Q,
     Editable->False], "[", "r", "]"}]}]}]], "Output",
 CellChangeTimes->{{3.7707020239727764`*^9, 3.7707020439782257`*^9}, 
   3.7707020846671867`*^9, 3.7707021149892855`*^9, {3.770702173364086*^9, 
   3.770702188580509*^9}}]
}, Open  ]],

Cell["This is easy to solve...", "Text",
 CellChangeTimes->{{3.7707021323878536`*^9, 3.770702141790501*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Qsol", "=", 
    RowBox[{
     RowBox[{"DSolve", "[", 
      RowBox[{
       RowBox[{"MSdefcomp", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", "Q", ",", "r"}], "]"}], 
     "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"\"\<Q[r]\>\"", "\[Equal]", 
   RowBox[{"Q", "[", "r", "]"}]}], "/.", "Qsol"}]}], "Input",
 CellChangeTimes->{{3.770702143757358*^9, 3.770702153053297*^9}, {
  3.77070221155212*^9, 3.770702232408076*^9}}],

Cell[BoxData[
 TemplateBox[{
  "Attributes","notfound",
   "\"Symbol \\!\\(\\*RowBox[{\\\"\\\\\\\"DSolveDispatchODE\\\\\\\"\\\"}]\\) \
not found.\"",2,51,4,16465889834559883370,"Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.770702153967004*^9, 3.7707021911467624`*^9, 
  3.770702233645581*^9}],

Cell[BoxData[
 RowBox[{"\<\"Q[r]\"\>", "\[Equal]", 
  FractionBox["1", 
   RowBox[{
    RowBox[{
     RowBox[{"-", 
      SuperscriptBox["r", "2"]}], " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}], "-", 
    RowBox[{"C", "[", "1", "]"}]}]]}]], "Output",
 CellChangeTimes->{3.7707021539874907`*^9, 3.770702191168994*^9, 
  3.770702233667335*^9}]
}, Open  ]],

Cell["\<\
To constrain the integration constant, we can put it back into the \
MSdefcomp...\
\>", "Text",
 CellChangeTimes->{{3.7707022466608753`*^9, 3.770702284460923*^9}, {
  3.7707023546233263`*^9, 3.7707023644012794`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"MSdefcomp", "/.", "Qsol"}], "//", "MatrixForm"}], "//", 
  "Simplify"}]], "Input",
 CellChangeTimes->{{3.770702285543454*^9, 3.7707023098166313`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"True", "True", "True"},
     {"True", 
      RowBox[{
       RowBox[{"1", "+", 
        RowBox[{"C", "[", "1", "]"}]}], "\[Equal]", "0"}], "True"},
     {"True", "True", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"1", "+", 
          RowBox[{"C", "[", "1", "]"}]}], ")"}], " ", 
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", "\[Theta]", "]"}]}], "\[Equal]", "0"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7707022937691317`*^9, 3.7707023106507883`*^9}, 
   3.770702369616687*^9}]
}, Open  ]],

Cell["The solution is now obvious.", "Text",
 CellChangeTimes->{{3.7707023721022263`*^9, 3.770702379766329*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"Qfinal", "=", 
    RowBox[{"Qsol", "/.", 
     RowBox[{
      RowBox[{"C", "[", "1", "]"}], "\[Rule]", 
      RowBox[{"-", "1"}]}]}]}], ";"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"maximally", " ", "symmetric", " ", "solution"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"\"\<Q[r]\>\"", "\[Equal]", 
    RowBox[{"Q", "[", "r", "]"}]}], "/.", "Qfinal"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"proof", " ", "of", " ", "solution"}], 
   "*)"}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"MSdefcomp", "/.", "Qfinal"}], "//", "MatrixForm"}], "//", 
  "Simplify"}]}], "Input",
 CellChangeTimes->{{3.7707023850594945`*^9, 3.770702443658477*^9}, {
  3.770702492158661*^9, 3.7707024944793053`*^9}}],

Cell[BoxData[
 RowBox[{"\<\"Q[r]\"\>", "\[Equal]", 
  FractionBox["1", 
   RowBox[{"1", "-", 
    RowBox[{
     SuperscriptBox["r", "2"], " ", 
     InterpretationBox[
      StyleBox["\[Kappa]",
       ShowAutoStyles->False,
       AutoSpacing->False],
      $CellContext`\[Kappa],
      Editable->False]}]}]]}]], "Output",
 CellChangeTimes->{3.7707024443114614`*^9, 3.770702494983466*^9}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {"True", "True", "True"},
     {"True", "True", "True"},
     {"True", "True", "True"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.7707024443114614`*^9, 3.770702494987322*^9}]
}, Open  ]],

Cell["\<\
Maximally symmetric spaces in 3D are then generally described by the metric...\
\>", "Text",
 CellChangeTimes->{{3.770702534000738*^9, 3.770702553342856*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{"G", "[", 
        RowBox[{
         RowBox[{"-", "\[Alpha]"}], ",", 
         RowBox[{"-", "\[Beta]"}]}], "]"}], "//", 
       RowBox[{"ToBasis", "[", "SP", "]"}]}], "//", "ComponentArray"}], "//", 
     "ToValues"}], ")"}], "/.", 
   RowBox[{"Q", "\[Rule]", 
    RowBox[{"Function", "[", 
     RowBox[{"r", ",", 
      RowBox[{
       RowBox[{"Q", "[", "r", "]"}], "/.", "Qfinal"}]}], "]"}]}]}], "//", 
  "MatrixForm"}]], "Input",
 CellChangeTimes->{{3.770702555407199*^9, 3.7707026176763897`*^9}}],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      FractionBox["1", 
       RowBox[{"1", "-", 
        RowBox[{
         InterpretationBox[
          StyleBox["\[Kappa]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Kappa],
          Editable->False], " ", 
         SuperscriptBox[
          InterpretationBox[
           StyleBox["r",
            ShowAutoStyles->False,
            AutoSpacing->False],
           $CellContext`r[],
           Editable->False], "2"]}]}]], "0", "0"},
     {"0", 
      SuperscriptBox[
       InterpretationBox[
        StyleBox["r",
         ShowAutoStyles->False,
         AutoSpacing->False],
        $CellContext`r[],
        Editable->False], "2"], "0"},
     {"0", "0", 
      RowBox[{
       SuperscriptBox[
        InterpretationBox[
         StyleBox["r",
          ShowAutoStyles->False,
          AutoSpacing->False],
         $CellContext`r[],
         Editable->False], "2"], " ", 
       SuperscriptBox[
        RowBox[{
         InterpretationBox[
          StyleBox["Sin",
           ShowAutoStyles->False,
           AutoSpacing->False],
          Sin,
          Editable->False], "[", 
         InterpretationBox[
          StyleBox["\[Theta]",
           ShowAutoStyles->False,
           AutoSpacing->False],
          $CellContext`\[Theta][],
          Editable->False], "]"}], "2"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{{3.7707025833758707`*^9, 3.7707026180965967`*^9}}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{901, 795},
WindowMargins->{{870, Automatic}, {Automatic, 227}},
FrontEndVersion->"11.0 for Microsoft Windows (64-bit) (September 21, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 122, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[705, 26, 119, 1, 70, "Section"],
Cell[827, 29, 404, 7, 49, "Text"],
Cell[CellGroupData[{
Cell[1256, 40, 367, 10, 69, "Input"],
Cell[CellGroupData[{
Cell[1648, 54, 239, 3, 22, "Print"],
Cell[1890, 59, 508, 10, 22, "Print"],
Cell[2401, 71, 260, 3, 22, "Print"],
Cell[2664, 76, 217, 2, 22, "Print"],
Cell[2884, 80, 200, 2, 22, "Print"],
Cell[3087, 84, 239, 3, 22, "Print"],
Cell[3329, 89, 513, 11, 22, "Print"],
Cell[3845, 102, 260, 3, 22, "Print"],
Cell[4108, 107, 237, 3, 22, "Print"],
Cell[4348, 112, 394, 5, 41, "Print"],
Cell[4745, 119, 239, 3, 22, "Print"],
Cell[4987, 124, 236, 3, 22, "Print"],
Cell[5226, 129, 506, 10, 22, "Print"],
Cell[5735, 141, 276, 3, 22, "Print"],
Cell[6014, 146, 236, 3, 22, "Print"],
Cell[6253, 151, 394, 5, 41, "Print"],
Cell[6650, 158, 237, 3, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[6914, 165, 165, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[7104, 172, 4314, 113, 435, "Input"],
Cell[CellGroupData[{
Cell[11443, 289, 547, 11, 22, "Print"],
Cell[11993, 302, 555, 11, 22, "Print"],
Cell[12551, 315, 729, 16, 22, "Print"],
Cell[13283, 333, 797, 17, 22, "Print"],
Cell[14083, 352, 643, 13, 22, "Print"],
Cell[14729, 367, 789, 17, 22, "Print"],
Cell[15521, 386, 809, 18, 22, "Print"],
Cell[16333, 406, 847, 18, 22, "Print"],
Cell[17183, 426, 743, 17, 22, "Print"],
Cell[17929, 445, 220, 3, 22, "Print"],
Cell[18152, 450, 594, 11, 22, "Print"],
Cell[18749, 463, 226, 3, 22, "Print"],
Cell[18978, 468, 755, 17, 22, "Print"],
Cell[19736, 487, 855, 18, 22, "Print"],
Cell[20594, 507, 751, 17, 22, "Print"],
Cell[21348, 526, 611, 12, 22, "Print"],
Cell[21962, 540, 357, 7, 22, "Print"],
Cell[22322, 549, 349, 7, 22, "Print"],
Cell[22674, 558, 361, 7, 22, "Print"],
Cell[23038, 567, 615, 12, 22, "Print"],
Cell[23656, 581, 531, 11, 22, "Print"],
Cell[24190, 594, 583, 12, 22, "Print"],
Cell[24776, 608, 597, 12, 22, "Print"],
Cell[25376, 622, 603, 12, 22, "Print"],
Cell[25982, 636, 543, 11, 22, "Print"],
Cell[26528, 649, 559, 11, 22, "Print"],
Cell[27090, 662, 724, 16, 24, "Print"],
Cell[27817, 680, 736, 17, 24, "Print"],
Cell[28556, 699, 571, 12, 22, "Print"],
Cell[29130, 713, 643, 13, 22, "Print"],
Cell[29776, 728, 795, 17, 22, "Print"],
Cell[30574, 747, 813, 18, 22, "Print"],
Cell[31390, 767, 853, 18, 22, "Print"],
Cell[32246, 787, 747, 17, 22, "Print"],
Cell[32996, 806, 743, 15, 22, "Print"],
Cell[33742, 823, 810, 18, 22, "Print"],
Cell[34555, 843, 571, 11, 22, "Print"],
Cell[35129, 856, 2032, 56, 29, "Print"],
Cell[37164, 914, 1675, 42, 29, "Print"],
Cell[38842, 958, 1675, 42, 29, "Print"],
Cell[40520, 1002, 2906, 75, 29, "Print"],
Cell[43429, 1079, 1867, 50, 29, "Print"],
Cell[45299, 1131, 1677, 42, 29, "Print"],
Cell[46979, 1175, 2904, 75, 29, "Print"],
Cell[49886, 1252, 2906, 75, 29, "Print"],
Cell[52795, 1329, 2313, 65, 29, "Print"],
Cell[55111, 1396, 619, 12, 22, "Print"],
Cell[55733, 1410, 764, 15, 22, "Print"]
}, Open  ]]
}, Open  ]],
Cell[56524, 1429, 679, 20, 51, "Text"],
Cell[CellGroupData[{
Cell[57228, 1453, 1432, 42, 145, "Input"],
Cell[58663, 1497, 516, 11, 22, "Print"],
Cell[59182, 1510, 5936, 157, 36, "Output"]
}, Open  ]],
Cell[65133, 1670, 159, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[65317, 1677, 467, 13, 88, "Input"],
Cell[65787, 1692, 2298, 65, 36, "Output"]
}, Open  ]],
Cell[68100, 1760, 248, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[68373, 1767, 764, 21, 69, "Input"],
Cell[69140, 1790, 5083, 157, 110, "Output"]
}, Open  ]],
Cell[74238, 1950, 412, 9, 30, "Text"],
Cell[CellGroupData[{
Cell[74675, 1963, 426, 11, 50, "Input"],
Cell[75104, 1976, 1030, 36, 49, "Output"]
}, Open  ]],
Cell[76149, 2015, 108, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[76282, 2020, 585, 17, 69, "Input"],
Cell[76870, 2039, 318, 7, 21, "Message"],
Cell[77191, 2048, 466, 15, 49, "Output"]
}, Open  ]],
Cell[77672, 2066, 226, 5, 30, "Text"],
Cell[CellGroupData[{
Cell[77923, 2075, 197, 5, 30, "Input"],
Cell[78123, 2082, 1187, 35, 63, "Output"]
}, Open  ]],
Cell[79325, 2120, 112, 1, 30, "Text"],
Cell[CellGroupData[{
Cell[79462, 2125, 864, 25, 145, "Input"],
Cell[80329, 2152, 389, 12, 47, "Output"],
Cell[80721, 2166, 710, 19, 63, "Output"]
}, Open  ]],
Cell[81446, 2188, 168, 3, 30, "Text"],
Cell[CellGroupData[{
Cell[81639, 2195, 609, 19, 50, "Input"],
Cell[82251, 2216, 1970, 64, 77, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

